( cd usr/lib/setup ; rm -rf pkgtool )
( cd usr/lib/setup ; ln -sf cpkgtool pkgtool )
( cd usr/lib/setup ; rm -rf setup )
( cd usr/lib/setup ; ln -sf hdsetup setup )
( cd sbin ; rm -rf setup )
( cd sbin ; ln -sf /usr/lib/setup/hdsetup setup )
( cd sbin ; rm -rf pkgtool )
( cd sbin ; ln -sf /usr/lib/setup/cpkgtool pkgtool )
( cd usr/lib/terminfo/l ; rm -rf luna68k )
( cd usr/lib/terminfo/l ; ln -sf ../l/luna luna68k )
( cd usr/lib/terminfo/v ; rm -rf vt100-am )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt100 vt100-am )
( cd usr/lib/terminfo/v ; rm -rf vt200 )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt220 vt200 )
( cd usr/lib/terminfo/v ; rm -rf vt300 )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt320 vt300 )
( cd usr/lib/terminfo/v ; rm -rf vt330 )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt340 vt330 )
( cd usr/lib/terminfo/v ; rm -rf vt400-24 )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt400 vt400-24 )
( cd usr/lib/terminfo/v ; rm -rf vs100-x10 )
( cd usr/lib/terminfo/v ; ln -sf ../x/x10term vs100-x10 )
( cd usr/lib/terminfo/v ; rm -rf vs100 )
( cd usr/lib/terminfo/v ; ln -sf ../x/xterm vs100 )
( cd usr/lib/terminfo/v ; rm -rf vis200 )
( cd usr/lib/terminfo/v ; ln -sf ../v/vi200 vis200 )
( cd usr/lib/terminfo/v ; rm -rf viewpoint3a+ )
( cd usr/lib/terminfo/v ; ln -sf ../v/vp3a+ viewpoint3a+ )
( cd usr/lib/terminfo/v ; rm -rf viewpoint90 )
( cd usr/lib/terminfo/v ; ln -sf ../v/vp90 viewpoint90 )
( cd usr/lib/terminfo/v ; rm -rf vc103 )
( cd usr/lib/terminfo/v ; ln -sf ../v/vc303 vc103 )
( cd usr/lib/terminfo/v ; rm -rf vc203 )
( cd usr/lib/terminfo/v ; ln -sf ../v/vc303 vc203 )
( cd usr/lib/terminfo/v ; rm -rf vc414h )
( cd usr/lib/terminfo/v ; ln -sf ../v/vc414 vc414h )
( cd usr/lib/terminfo/v ; rm -rf vt-61 )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt61 vt-61 )
( cd usr/lib/terminfo/v ; rm -rf vt61.5 )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt61 vt61.5 )
( cd usr/lib/terminfo/v ; rm -rf vs100-tsim )
( cd usr/lib/terminfo/v ; ln -sf ../v/vs100t vs100-tsim )
( cd usr/lib/terminfo/v ; rm -rf vt100-nam )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt100nam vt100-nam )
( cd usr/lib/terminfo/v ; rm -rf vt100-w-am )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt100-w vt100-w-am )
( cd usr/lib/terminfo/v ; rm -rf vt100-nam-w )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt100-w-nam vt100-nam-w )
( cd usr/lib/terminfo/v ; rm -rf vt100-w-nav )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt100-nav-w vt100-w-nav )
( cd usr/lib/terminfo/v ; rm -rf vt100-s-top )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt100-s vt100-s-top )
( cd usr/lib/terminfo/v ; rm -rf vt100-top-s )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt100-s vt100-top-s )
( cd usr/lib/terminfo/v ; rm -rf vt100-bot-s )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt100-s-bot vt100-bot-s )
( cd usr/lib/terminfo/v ; rm -rf vt200-w )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt220-w vt200-w )
( cd usr/lib/terminfo/v ; rm -rf v200-nam )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt220-nam v200-nam )
( cd usr/lib/terminfo/v ; rm -rf v320n )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt320nam v320n )
( cd usr/lib/terminfo/v ; rm -rf vt300-nam )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt320-nam vt300-nam )
( cd usr/lib/terminfo/v ; rm -rf vt300-w )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt320-w vt300-w )
( cd usr/lib/terminfo/v ; rm -rf vt300-w-nam )
( cd usr/lib/terminfo/v ; ln -sf ../v/vt320-w-nam vt300-w-nam )
( cd usr/lib/terminfo/v ; rm -rf vs100s )
( cd usr/lib/terminfo/v ; ln -sf ../x/xterms vs100s )
( cd usr/lib/terminfo/v ; rm -rf visual )
( cd usr/lib/terminfo/v ; ln -sf ../v/vi200-f visual )
( cd usr/lib/terminfo/v ; rm -rf visual603 )
( cd usr/lib/terminfo/v ; ln -sf ../v/vi603 visual603 )
( cd usr/lib/terminfo/v ; rm -rf viewpoint60 )
( cd usr/lib/terminfo/v ; ln -sf ../v/vp60 viewpoint60 )
( cd usr/lib/terminfo/v ; rm -rf vc403a )
( cd usr/lib/terminfo/v ; ln -sf ../v/vc303a vc403a )
( cd usr/lib/terminfo/x ; rm -rf x820 )
( cd usr/lib/terminfo/x ; ln -sf ../x/xerox820 x820 )
( cd usr/lib/terminfo/x ; rm -rf x1720 )
( cd usr/lib/terminfo/x ; ln -sf ../x/xerox1720 x1720 )
( cd usr/lib/terminfo/x ; rm -rf x1750 )
( cd usr/lib/terminfo/x ; ln -sf ../x/xerox1720 x1750 )
